# This file is part of the faebryk project
# SPDX-License-Identifier: MIT

def version():
    return "1.0.0"
